@@ -1,7 +1,7 @@
-/* $Id: control.cc 888 2011-01-21 08:52:19Z dreibh $
+/* $Id: control.cc 1140 2011-11-23 06:43:27Z dreibh $
  *
  * Network Performance Meter
- * Copyright (C) 2009-2011 by Thomas Dreibholz
+ * Copyright (C) 2009-2012 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -155,6 +155,7 @@ bool performNetPerfMeterAddFlow(MessageReader* messageReader,
    addFlowMsg->Header.Type   = NETPERFMETER_ADD_FLOW;
    addFlowMsg->Header.Flags  = 0x00;
    addFlowMsg->CCID          = flow->getTrafficSpec().CCID;
+   addFlowMsg->CMT           = flow->getTrafficSpec().CMT;
    if(flow->getTrafficSpec().CMT > 0) {
       addFlowMsg->Header.Flags |= NPMAF_USE_CMT;   /* Backward compatibility */
    }
@@ -227,7 +228,8 @@ bool performNetPerfMeterIdentifyFlow(MessageReader* messageReader,
    // ====== Sent NETPERFMETER_IDENTIFY_FLOW to remote node =================
    unsigned int maxTrials = 1;
    if( (flow->getTrafficSpec().Protocol != IPPROTO_SCTP) &&
-       (flow->getTrafficSpec().Protocol != IPPROTO_TCP) ) {
+       (flow->getTrafficSpec().Protocol != IPPROTO_TCP) &&
+       (flow->getTrafficSpec().Protocol != IPPROTO_MPTCP) ) {
       // SCTP and TCP are reliable transport protocols => no retransmissions
       maxTrials = IDENTIFY_MAX_TRIALS;
    }
@@ -758,7 +760,7 @@ static bool handleNetPerfMeterAddFlow(MessageReader*                    messageR
 
       if(trafficSpec.CMT == 0x00) {   /* Backward compatibility */
          if(addFlowMsg->Header.Flags & (NPMAF_USE_CMT|NPMAF_USE_RP)) {
-            trafficSpec.CMT = NPAF_CMTRP;
+            trafficSpec.CMT = NPAF_CMTRPv1;
          }
          else if(addFlowMsg->Header.Flags & NPMAF_USE_CMT) {
             trafficSpec.CMT = NPAF_CMT;
@@ -877,8 +879,8 @@ static bool handleNetPerfMeterStop(MessageReader*                 messageReader,
 
    if(gOutputVerbosity >= NPFOV_STATUS) {
       std::cout << std::endl << "Stopping measurement "
-               << format("$%llx", (unsigned long long)measurementID)
-               << " ..." << std::endl;
+                << format("$%llx", (unsigned long long)measurementID)
+                << " ..." << std::endl;
    }
 
    // ====== Stop flows =====================================================
@@ -938,6 +940,7 @@ static void handleControlAssocShutdown(const sctp_assoc_t assocID)
       if(flow->getRemoteControlAssocID() == assocID) {
          Measurement* measurement = flow->getMeasurement();
          if(measurement) {
+            printf("delete2=%p\n", measurement);
             delete measurement;
          }
          delete flow;
