@@ -1,7 +1,7 @@
-/* $Id: cpustatus.h 873 2011-01-02 17:37:23Z dreibh $
+/* $Id: cpustatus.h 1147 2011-11-26 17:42:24Z michael.tuexen $
  *
  * Network Performance Meter
- * Copyright (C) 2009-2011 by Thomas Dreibholz
+ * Copyright (C) 2009-2012 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,9 @@
 
 #include <stdio.h>
 #include <assert.h>
+#ifdef __APPLE__
+#include <mach/mach.h>
+#endif
 
 
 class CPUStatus
@@ -62,6 +65,14 @@ class CPUStatus
 #elif defined __linux__
    typedef unsigned long long tick_t;
    FILE*               ProcStatFD;
+#elif __APPLE__
+#ifdef USE_PER_CPU_STATISTICS
+   typedef unsigned int tick_t;
+   host_priv_t         host_priv;
+#else
+   typedef natural_t tick_t;
+#endif
+   host_name_port_t    host;
 #endif
    unsigned int        CPUs;
    tick_t*             CpuTimes;
