@@ -1,4 +1,4 @@
-/* $Id: flow.cc 1140 2011-11-23 06:43:27Z dreibh $
+/* $Id: flow.cc 1384 2012-05-29 09:48:36Z dreibh $
  *
  * Network Performance Meter
  * Copyright (C) 2009-2012 by Thomas Dreibholz
@@ -13,7 +13,7 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
- * You should have relReceived a copy of the GNU General Public License
+ * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *
  * Contact: dreibh@iem.uni-due.de
@@ -1200,19 +1200,22 @@ void Flow::run()
 // ###### Configure socket parameters #######################################
 bool Flow::configureSocket(const int socketDescriptor)
 {
-    int bufferSize = TrafficSpec.RcvBufferSize;
-    if(ext_setsockopt(socketDescriptor, SOL_SOCKET, SO_RCVBUF, &bufferSize, sizeof(bufferSize)) < 0) {
-        std::cerr << "ERROR: Failed to configure receive buffer size on SCTP socket (SO_RCVBUF option) - "
-                  << strerror(errno) << "!" << std::endl;
-        return(false);
+    if(TrafficSpec.RcvBufferSize != 0) {
+       int bufferSize = TrafficSpec.RcvBufferSize;
+       if(ext_setsockopt(socketDescriptor, SOL_SOCKET, SO_RCVBUF, &bufferSize, sizeof(bufferSize)) < 0) {
+           std::cerr << "ERROR: Failed to configure receive buffer size on SCTP socket (SO_RCVBUF option) - "
+                     << strerror(errno) << "!" << std::endl;
+           return(false);
+       }
     }
-    bufferSize = TrafficSpec.SndBufferSize;
-    if(ext_setsockopt(socketDescriptor, SOL_SOCKET, SO_SNDBUF, &bufferSize, sizeof(bufferSize)) < 0) {
-        std::cerr << "ERROR: Failed to configure send buffer size on SCTP socket (SO_SNDBUF option) - "
-                  << strerror(errno) << "!" << std::endl;
-        return(false);
+    if(TrafficSpec.SndBufferSize != 0) {
+       int bufferSize = TrafficSpec.SndBufferSize;
+       if(ext_setsockopt(socketDescriptor, SOL_SOCKET, SO_SNDBUF, &bufferSize, sizeof(bufferSize)) < 0) {
+           std::cerr << "ERROR: Failed to configure send buffer size on SCTP socket (SO_SNDBUF option) - "
+                     << strerror(errno) << "!" << std::endl;
+           return(false);
+       }
     }
-
     if(TrafficSpec.Protocol == IPPROTO_SCTP) {
 #ifdef SCTP_CMT_ON_OFF
         struct sctp_assoc_value cmtOnOff;
