@@ -1,7 +1,7 @@
-/* $Id: netperfmeterpackets.h 988 2011-02-11 08:58:57Z dreibh $
+/* $Id: netperfmeterpackets.h 1143 2011-11-23 07:24:48Z dreibh $
  *
  * Network Performance Meter
- * Copyright (C) 2009-2011 by Thomas Dreibholz
+ * Copyright (C) 2009-2012 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -107,7 +107,9 @@ struct NetPerfMeterAddFlowMessage
 
 #define NPAF_PRIMARY_PATH 0x00
 #define NPAF_CMT          0x01
-#define NPAF_CMTRP        0x02
+#define NPAF_CMTRPv1      0x02
+#define NPAF_CMTRPv2      0x03
+#define NPAF_LikeMPTCP    0x04
 
 
 struct NetPerfMeterRemoveFlowMessage
@@ -149,7 +151,7 @@ struct NetPerfMeterDataMessage
    uint64_t           ByteSeqNumber;
    uint64_t           TimeStamp;
 
-   char               Payload[];
+   unsigned char      Payload[];
 } __attribute__((packed));
 
 #define NPMDF_FRAME_BEGIN (1 << 0)
